@@ -1,5 +1,7 @@
 import pygame
+import webbrowser
 import pyttsx3
+import pyperclip
 from transformers import AutoTokenizer, AutoModelForCausalLM, pipeline
 import builtins
 import tkinter as tk
@@ -22,22 +24,74 @@ import pygame
 import time
 from pathlib import Path
 import os
+from gtts import gTTS, lang as gtts_langs
+from pathlib import Path
+import ctypes
+import speech_recognition as sr
+import platform
+import psutil
+import socket
+import datetime
+import pytz
+import random
+import string
+def get_system_summary():
+    try:
+        os_info = platform.system() + " " + platform.release()
+        cpu_info = platform.processor()
+        ram_info = f"{round(psutil.virtual_memory().total / (1024**3))} GB"
+        python_ver = platform.python_version()
+        ip = socket.gethostbyname(socket.gethostname())
+        tz = datetime.datetime.now(pytz.timezone("Asia/Tehran")).tzname()
+def generate_password(length=12, strength="strong"):
+    if strength == "simple":
+        chars = string.ascii_lowercase
+    elif strength == "medium":
+        chars = string.ascii_letters + string.digits
+    else:
+        chars = string.ascii_letters + string.digits + string.punctuation
+
+    return ''.join(random.choice(chars) for _ in range(length))
+
+def browser(url):
+    webbrowser.open(url)
+def run_app(path):
+    try:
+        os.startfile(path)
+    except Exception as e:
+        print(FileNotFoundError ("TahaError:", e))
+def get_file_size(path: str):
+    size = os.path.getsize(path)
+    for unit in ['B', 'KB', 'MB', 'GB']:
+        if size < 1024:
+            return f"{size:.2f} {unit}"
+        size /= 1024
+def count_words(text: str):
+    return len(text.strip().split())
+def get_day_name(date_str: str):
+    date_obj = datetime.datetime.strptime(date_str, "%Y-%m-%d")
+    return date_obj.strftime("%A")
+
 def get_downloads_dir():
     return Path(os.path.expanduser("~/Downloads"))
 
-now = datetime.now()
-hour = now.hour
-minute = now.minute
-second = now.second
-microsecond = now.microsecond
-
-def ai_chat(prompt, lang, max_length=100):
-    tokenizer = AutoTokenizer.from_pretrained(f"HooshvareLab/gpt2-{lang}")
-    model = AutoModelForCausalLM.from_pretrained(f"HooshvareLab/gpt2-{lang}")
-    generator = pipeline("text-generation", model=model, tokenizer=tokenizer)
-    result = generator(prompt, max_length=max_length, num_return_sequences=1)
-    return result[0]["generated_text"]
-
+def system(action):
+    """action :
+            sleep
+            shut_down
+            log_out
+            restart
+            """
+    if action == "shut_down":
+        os.system("shutdown /s /t 0")
+    elif action == "restart":
+        os.system("shutdown /r /t")
+    elif action == "log_out":
+        os.system("shutdown -1")
+    elif action == "sleep":
+        os.system("rundll32.exe powrprof.dll,SetSuspendState 0,1,0")
+def copy_text(text):
+    pyperclip.copy(text)
 def save_var(local_or_name, value):
     with open (local_or_name, "w") as f:
         f.write(str(value))
@@ -91,9 +145,9 @@ def mouseY():
     screen = t.Screen()
     return screen.window_height() // 2 - (screen.cv.winfo_pointery() - screen.cv.winfo_rooty())
 def hidecursor():
-    root = tk.Tk()
-    root.config(cursor = "none")
-    root.mainloop()
+    ctypes.windll.user32.ShowCursor(False)
+def showcursor():
+    ctypes.windll.user32.ShowCursor(True)
 def shapecursor(a):
     root = tk.Tk()
     root.config (cursor = a)
@@ -139,15 +193,28 @@ def text_to_speech(txt, language, yourMP3name):
     while pygame.mixer.music.get_busy():
         time.sleep(0.1)
 
+import os
+
+def search_real_usage(keyword, path):
+    ignore_patterns = [
+        f'def search_keyword_in_project',
+        f'search_keyword_in_project("{keyword}"',
+        f'search_real_usage("{keyword}"'
+    ]
+
+    for root, dirs, files in os.walk(path):
+        for file in files:
+            if file.endswith(".py"):
+                full_path = os.path.join(root, file)
+                with open(full_path, encoding="utf-8", errors="ignore") as f:
+                    for i, line in enumerate(f, start=1):
+                        line_stripped = line.strip()
+                        if keyword in line_stripped and not any(p in line_stripped for p in ignore_patterns):
+                            print(f"📍 Found in {full_path}, line {i}:\n  {line_stripped}")
+
 def get_downloads_dir():
     return Path(os.path.expanduser("~/Downloads"))
 
-from gtts import gTTS, lang as gtts_langs
-import pygame
-import time
-from pathlib import Path
-import os
-
 def get_downloads_dir():
     return Path(os.path.expanduser("~/Downloads"))
 
@@ -160,36 +227,6 @@ def get_unique_filename(base_name="voice", ext=".mp3", folder=None):
             return filename
         i += 1
 
-def speak(text, lang="auto"):
-    # تشخیص زبان
-    if lang == "auto":
-        lang = "fa" if any('\u0600' <= ch <= '\u06FF' for ch in text) else "en"
-
-    # بررسی پشتیبانی gTTS
-    supported_langs = gtts_langs.tts_langs()
-    if lang not in supported_langs:
-        fallback = "ar" if lang == "fa" else "en"
-        print(f"[!] زبان '{lang}' توسط gTTS پشتیبانی نمی‌شود. استفاده از جایگزین: '{fallback}'")
-        lang = fallback
-
-    # ساخت فایل با نام جديد
-    downloads = get_downloads_dir()
-    downloads.mkdir(parents=True, exist_ok=True)
-    filename = get_unique_filename(base_name="voice", ext=".mp3", folder=downloads)
-
-    # ساخت فایل صوتی
-    tts = gTTS(text=text, lang=lang)
-    tts.save(str(filename))
-
-    # پخش با صدای مرد (در صورت وجود)
-    pygame.mixer.init()
-    pygame.mixer.music.load(str(filename))
-    pygame.mixer.music.set_volume(1.0)
-    pygame.mixer.music.play()
-
-    while pygame.mixer.music.get_busy():
-        time.sleep(0.1)
-
 def clock(unit):
     now = datetime.now()
     if unit == "hour":
@@ -202,9 +239,8 @@ def clock(unit):
         return now.microsecond
     else:
         return "Invalid unit"
-
 __all__ = [
-    "text_to_speech", "randcolor", "rgbcolor", "upload_gif",
-    "save_var", "load_var", "getping", "clock", "mouseX", "mouseY",
-    "key", "click", "getcolor", "rc", "ri", "leftclick", "middleclick", "rightclick", "play_mp3", "speak"
+    "text_to_speech", "randcolor", "rgbcolor", "upload_gif", "search_real_usage", "showcursor","count_words", "get_day_name", "get_system_summary",
+    "save_var", "load_var", "getping", "clock", "mouseX", "mouseY","hidecursor", "speak","shapecursor","run_app", "get_file_size", "generate_password",
+    "key", "click", "getcolor", "rc", "ri", "leftclick", "middleclick", "rightclick", "play_mp3", "system", "copy_text", "browser"
 ]
